"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const cross_spawn_1 = __importDefault(require("cross-spawn"));
const yargs_parser_1 = __importDefault(require("yargs-parser"));
const utils_1 = require("./utils");
const args = process.argv.slice(3);
const parsedArgs = (0, yargs_parser_1.default)(args);
function lint() {
    const configPath = getEslintConfigPath();
    const filesToLint = getFilesToLint();
    const otherArgs = args.filter(arg => !parsedArgs._.includes(arg));
    const result = cross_spawn_1.default.sync(path_1.default.join(utils_1.appDirectory, "./node_modules/.bin/eslint"), ["--config", configPath, "--ext", ".js,.ts", ...otherArgs, ...filesToLint], { stdio: "inherit" });
    if (result.error) {
        console.error(result.error);
    }
    return typeof result.status === "number" ? result.status : 1;
}
function getEslintConfigPath() {
    if (parsedArgs.config) {
        return parsedArgs.config;
    }
    if ((0, utils_1.hasFile)(".eslintrc")) {
        return ".eslintrc";
    }
    if ((0, utils_1.hasFile)(".eslintrc.json")) {
        return ".eslintrc.json";
    }
    return path_1.default.join(__dirname, "../.eslintrc.json");
}
function getFilesToLint() {
    const filesToLint = parsedArgs._.map(fileName => path_1.default.join(utils_1.appDirectory, fileName));
    return filesToLint.length > 0 ? filesToLint : ["."];
}
exports.default = lint;
